==> nextcloud-25.0.7.tgz: nextcloud/apps/photos/l10n/da.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Offentligt link",
    "Photos" : "Billeder",
    "Your memories under your control" : "Dine minder under din egen kontrol",
    "All media" : "Alle medier",
    "Videos" : "Videoer",
    "Albums" : "Album",
    "People" : "Personer",
    "Folders" : "Mapper",
    "Favorites" : "Favoritter",
    "On this day" : "På denne dag",
    "Shared with you" : "Shared with you",
    "Tags" : "Mærker",
    "Photos settings" : "Indstillinger for fotos",
    "Name of the album" : "Albummets navn",
    "Location of the album" : "Placering af albummet",
    "Go back to the previous view." : "Gå tilbage til den forrige visning.",
    "Back" : "Tilbage",
    "Go to the add collaborators view." : "Gå til visningen Tilføj samarbejdspartnere.",
    "Add collaborators" : "Tilføj samarbejdspartnere",
    "Save." : "Gem.",
    "Create the album." : "Opret albummet.",
    "Save" : "Gem",
    "Create album" : "Opret album",
    "Back to the new album form." : "Tilbage til den nye albumform.",
    "Add to Album" : "Føj til album",
    "Create a new album." : "Opret et nyt album.",
    "Create new album" : "Opret nyt album",
    "New album" : "Nyt album",
    "_%n item_::_%n photos and videos_" : ["%n enheder","%n fotos og videoer"],
    "_Share with %n user_::_Share with %n users_" : ["Del med %n bruger","Del med %n brugere"],
    "Public link copied!" : "Offentlig link kopieret!",
    "Copy public link" : "Kopier offentligt link",
    "An error occurred" : "Der var en fejl",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos"],
    "Select image {imageName}" : "Vælg billede {imageName}",
    "The file is in the favorites" : "Filen er i favoritterne",
    "Open the full size \"{name}\" image" : "Åbn billedet \"{name}\" i fuld størrelse",
    "Add to {destination}" : "Føj til {destination}",
    "Open the \"{name}\" sub-directory" : "Åbn \"{name}\" under direktoriet",
    "Back to {folder}" : "Tilbage til {folder}",
    "Share this folder" : "Del denne mappe",
    "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
    "Enable squared photos view" : "Aktiver kvadratisk fotovisning",
    "Default Photos upload and Albums location" : "Standard upload af fotos og albumplacering",
    "Select the default location for your media" : "Vælg standardplaceringen for dine medier",
    "Invalid location selected" : "Ugyldig placering er valgt",
    "View" : "Vis",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Fjern fra favoritter",
    "This folder does not exist" : "Denne mappe findes ikke",
    "No photos in here" : "Ingen billeder her",
    "Shared by" : "Delt af",
    "Shared albums" : "Delte album",
    "No tags yet" : "Ingen tags endnu",
    "Photos with tags will show up here" : "Billeder med tags vil vise sig her",
    "Add" : "Tilføj",
    "Delete selection" : "Slet valgte",
    "Tagged photos" : "Markerede billeder",
    "Failed to delete {fileName}." : "Kunne ikke slette {fileName}.",
    "Your photos" : "Dine billeder",
    "Your videos" : "Dine videoer",
    "Your folders" : "Dine mapper",
    "Locations" : "Sted",
    "Settings" : "Indstillinger"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.8.tgz: nextcloud/apps/photos/l10n/da.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Offentligt link",
    "Photos" : "Billeder",
    "Your memories under your control" : "Dine minder under din egen kontrol",
    "All media" : "Alle medier",
    "Videos" : "Videoer",
    "Albums" : "Album",
    "People" : "Personer",
    "Folders" : "Mapper",
    "Favorites" : "Favoritter",
    "On this day" : "På denne dag",
    "Shared with you" : "Shared with you",
    "Tags" : "Mærker",
    "Photos settings" : "Indstillinger for fotos",
    "Name of the album" : "Albummets navn",
    "Location of the album" : "Placering af albummet",
    "Go back to the previous view." : "Gå tilbage til den forrige visning.",
    "Back" : "Tilbage",
    "Go to the add collaborators view." : "Gå til visningen Tilføj samarbejdspartnere.",
    "Add collaborators" : "Tilføj samarbejdspartnere",
    "Save." : "Gem.",
    "Create the album." : "Opret albummet.",
    "Save" : "Gem",
    "Create album" : "Opret album",
    "Back to the new album form." : "Tilbage til den nye albumform.",
    "Add to Album" : "Føj til album",
    "Shared by" : "Delt af",
    "Create a new album." : "Opret et nyt album.",
    "Create new album" : "Opret nyt album",
    "New album" : "Nyt album",
    "_%n item_::_%n photos and videos_" : ["%n enheder","%n fotos og videoer"],
    "No recommendations. Start typing." : "Ingen anbefalinger. Begynd at skrive.",
    "Public link copied!" : "Offentlig link kopieret!",
    "Copy public link" : "Kopier offentligt link",
    "An error occurred" : "Der var en fejl",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos"],
    "Select image {imageName}" : "Vælg billede {imageName}",
    "The file is in the favorites" : "Filen er i favoritterne",
    "Open the full size \"{name}\" image" : "Åbn billedet \"{name}\" i fuld størrelse",
    "Add to {destination}" : "Føj til {destination}",
    "Open the \"{name}\" sub-directory" : "Åbn \"{name}\" under direktoriet",
    "Back to {folder}" : "Tilbage til {folder}",
    "Share this folder" : "Del denne mappe",
    "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
    "Enable squared photos view" : "Aktiver kvadratisk fotovisning",
    "Default Photos upload and Albums location" : "Standard upload af fotos og albumplacering",
    "Select the default location for your media" : "Vælg standardplaceringen for dine medier",
    "Invalid location selected" : "Ugyldig placering er valgt",
    "View" : "Vis",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Fjern fra favoritter",
    "This folder does not exist" : "Denne mappe findes ikke",
    "No photos in here" : "Ingen billeder her",
    "No tags yet" : "Ingen tags endnu",
    "Photos with tags will show up here" : "Billeder med tags vil vise sig her",
    "Add" : "Tilføj",
    "Delete selection" : "Slet valgte",
    "Tagged photos" : "Markerede billeder",
    "Failed to delete {fileName}." : "Kunne ikke slette {fileName}.",
    "Locations" : "Sted",
    "_Share with %n user_::_Share with %n users_" : ["Del med %n bruger","Del med %n brugere"],
    "Shared albums" : "Delte album"
},
"nplurals=2; plural=(n != 1);");
